@@ -4,7 +4,8 @@
 #' Species (WORMS).
 #'
 #' @export
-#' @param query character; A vector of common or scientific names.
+#' @param query character; A vector of common or scientific names. Or, a
+#' `taxon_state` object (see [taxon-state])
 #' @param searchtype character; One of 'scientific' or 'common', or any unique
 #' abbreviation
 #' @param accepted logical; If TRUE, removes names that are not accepted valid
@@ -30,16 +31,15 @@
 #' @seealso [classification()]
 #'
 #' @examples \dontrun{
-#' (x <- get_wormsid('Platanista gangetica'))
+#' (x <- get_wormsid('Gadus morhua'))
 #' attributes(x)
 #' attr(x, "match")
 #' attr(x, "multiple_matches")
 #' attr(x, "pattern_match")
 #' attr(x, "uri")
 #'
-#' get_wormsid('Gadus morhua')
 #' get_wormsid('Pomatomus saltatrix')
-#' get_wormsid(c("Platanista gangetica", "Lichenopora neapolitana"))
+#' get_wormsid(c("Gadus morhua", "Lichenopora neapolitana"))
 #'
 #' # by common name
 #' get_wormsid("dolphin", 'common')
@@ -89,23 +89,39 @@
 get_wormsid <- function(query, searchtype = "scientific", accepted = FALSE,
                       ask = TRUE, messages = TRUE, rows = NA, ...) {
 
+  assert(query, c("character", "taxon_state"))
   assert(searchtype, "character")
   assert(accepted, "logical")
   assert(ask, "logical")
   assert(messages, "logical")
   assert_rows(rows)
 
-  fun <- function(x, searchtype, ask, messages, ...) {
+  if (inherits(query, "character")) {
+    tstate <- taxon_state$new(class = "wormsid", names = query)
+    items <- query
+  } else {
+    assert_state(query, "wormsid")
+    tstate <- query
+    query <- tstate$taxa_remaining()
+    items <- c(query, tstate$taxa_completed())
+  }
+
+  prog <- progressor$new(items = items, suppress = !messages)
+  done <- tstate$get()
+  for (i in seq_along(done)) prog$completed(names(done)[i], done[[i]]$att)
+  prog$prog_start()
+
+  for (i in seq_along(query)) {
     direct <- FALSE
-    mssg(messages, "\nRetrieving data for taxon '", x, "'\n")
+    mssg(messages, "\nRetrieving data for taxon '", query[i], "'\n")
 
     if (!searchtype %in% c("scientific", "common")) {
       stop("'searchtype' must be one of 'scientific' or 'common'", call. = FALSE)
     }
     wmdf <- switch(
       searchtype,
-      scientific = worms_worker(x, worrms::wm_records_name, rows, ...),
-      common = worms_worker(x, worrms::wm_records_common, rows, ...)
+      scientific = worms_worker(query[i], worrms::wm_records_name, rows, ...),
+      common = worms_worker(query[i], worrms::wm_records_common, rows, ...)
     )
     mm <- NROW(wmdf) > 1
 
@@ -139,7 +155,7 @@ get_wormsid <- function(query, searchtype = "scientific", accepted = FALSE,
       # check for direct match
       if (nrow(wmdf) > 1) {
         names(wmdf)[grep("scientificname", names(wmdf))] <- "target"
-        matchtmp <- wmdf[tolower(wmdf$target) %in% tolower(x), "id"]
+        matchtmp <- wmdf[tolower(wmdf$target) %in% tolower(query[i]), "id"]
         if (length(matchtmp) == 1) {
           wmid <- matchtmp
           direct <- TRUE
@@ -164,7 +180,7 @@ get_wormsid <- function(query, searchtype = "scientific", accepted = FALSE,
           # prompt
           message("\n\n")
           print(wmdf)
-          message("\nMore than one WORMS ID found for taxon '", x, "'!\n
+          message("\nMore than one WORMS ID found for taxon '", query[i], "'!\n
                   Enter rownumber of taxon (other inputs will return 'NA'):\n") # prompt
           take <- scan(n = 1, quiet = TRUE, what = 'raw')
 
@@ -184,7 +200,7 @@ get_wormsid <- function(query, searchtype = "scientific", accepted = FALSE,
           }
         } else {
           if (length(wmid) != 1) {
-            warning(sprintf(m_more_than_one_found, "Worms ID", x), 
+            warning(sprintf(m_more_than_one_found, "Worms ID", query[i]), 
               call. = FALSE)
             wmid <- NA_character_
             att <- m_na_ask_false
@@ -193,27 +209,21 @@ get_wormsid <- function(query, searchtype = "scientific", accepted = FALSE,
       }
 
     }
-
-    data.frame(
-      wmid = as.character(wmid),
-      att = att,
-      multiple = mm,
-      direct = direct,
-      stringsAsFactors = FALSE)
+    res <- list(id = as.character(wmid), att = att, multiple = mm,
+      direct = direct)
+    prog$completed(query[i], att)
+    prog$prog(att)
+    tstate$add(query[i], res)
   }
-  query <- as.character(query)
-  outd <- ldply(query, fun, searchtype, ask, messages, ...)
-  out <- outd$wmid
-  attr(out, 'match') <- outd$att
-  attr(out, 'multiple_matches') <- outd$multiple
-  attr(out, 'pattern_match') <- outd$direct
-  if ( !all(is.na(out)) ) {
-    urlmake <- na.omit(out)
-    attr(out, 'uri') <-
-      sprintf('http://www.marinespecies.org/aphia.php?p=taxdetails&id=%s', urlmake)
-  }
-  class(out) <- "wormsid"
-  return(out)
+  out <- tstate$get()
+  ids <- structure(pluck_un(out, "id", ""), class = "wormsid",
+    match = pluck_un(out, "att", ""),
+    multiple_matches = pluck_un(out, "multiple", logical(1)),
+    pattern_match = pluck_un(out, "direct", logical(1))
+  )
+  on.exit(prog$prog_summary(), add = TRUE)
+  on.exit(tstate$exit, add = TRUE)
+  add_uri(ids, get_url_templates$worms)
 }
 
 try_df <- function(expr) {
