@@ -24,6 +24,17 @@ test_that("eubon_search works", {
   expect_equal(NROW(cc), 2)
 })
 
+test_that("eubon_search fails well", {
+  expect_error(eubon_search("Prionus", limit = "asdf"), 
+    "limit must be of class numeric, integer", class = "error")
+  expect_error(eubon_search("Prionus", page = "asdf"), 
+    "page must be of class numeric, integer", class = "error")
+  expect_error(eubon_search("Prionus", timeout = "adf"), 
+    "timeout must be of class numeric", class = "error")
+  expect_error(eubon_search("Prionus", addParentTaxon = 5), 
+    "addParentTaxon must be of class logical", class = "error")
+})
+
 # vcr::use_cassette("eubon_search_fails", {
 #   test_that("eubon_search fails well", {
 #     expect_error(eubon_search("Salmo", 'asdfdf'),
@@ -34,9 +45,9 @@ test_that("eubon_search works", {
 #   })
 # }, preserve_exact_body_bytes = TRUE)
 
-test_that("eubon and eubon_search are aliases of each other", {
+test_that("eubon and eubon_search are no longer aliases - eubon is defunct", {
   skip_on_cran()
 
-  expect_identical(eubon, eubon_search)
+  expect_error(eubon(), "use eubon_search", class = "error")
 })
 
