@@ -37,9 +37,11 @@ test_that("ipni_search works with different output formats", {
 })
 
 test_that("ipni_search fails correctly", {
+  expect_error(ipni_search(output = "foobar"), "'arg' should be one of")
+
   vcr::use_cassette("ipni_search_no_results", {
-    expect_error(ipni_search(), "No results")
-    expect_error(ipni_search(family = 5), "No results")
+    expect_warning(ipni_search(), "No data")
+    expect_warning(ipni_search(family = 5), "No data")
     expect_warning(ipni_search(genus = "adfasdfasffd"), "No data found")
   })
 })
